/**
 * \file bmc_dev_oem_asus.h
 *
 * Description: ASUS OEM commands
 *
 */

#ifndef __BMC_DEV_OEM_ASUS_H__
#define __BMC_DEV_OEM_ASUS_H__

#define I2C_1_NUMBER	1
#define I2C_2_NUMBER	2
#define I2C_3_NUMBER	3
#define I2C_4_NUMBER	4
#define I2C_5_NUMBER	5

#define IPMI_ERR_ASUS_CMD_SPECIFIC_CODES_I2C_ACCESS_FAIL		0x80
#define IPMI_ERR_ASUS_CMD_SPECIFIC_CODES_OEM_CMD_FAIL			0x81
#define IPMI_ERR_ASUS_CMD_SPECIFIC_CODES_FRU_FILE_ACCESS_FAIL	0x82

#define IPMI_ERR_MWR_LOST_ARBIT 0xB1
#define IPMI_ERR_MWR_BUS_ERR    0xB2
#define IPMI_ERR_MWR_NAK        0xB3
#define IPMI_ERR_MWR_TRUNC      0xB4

#define ENABLE_DO_LOG_ERR	1
#define DISABLE_DO_LOG_ERR	0

/* #define ASUS_GPIO_LED */
#define ASUS_w83601_LED

#define PCA9545_SLAVE_ADDR	0x71	//Bus#2
#define W83601R_SLAVE_ADDR	0x18	//Bus#2
#define SEEPROM_SLAVE_ADDR	0x50	//Bus#4

/**
 * Initializes the BMC ASUS-OEM device and registers it at the BMC core.
 *
 * @return PP_SUC (0) if success
 *         PP_ERR (-1) if error
 */
int pp_bmc_dev_oem_asus_init(void);

/**
 * Finishes the BMC ASUS-OEM device and unregisters it at the BMC core.
 */
void pp_bmc_dev_oem_asus_cleanup(void);


//protocol_type value mode definition
// 0 : tx_byte		(send byte	<null offset>		: PCF8574, ... etc)
// 1 : tx_byte_data	(write byte	<one byte offset>	: ADT7463, ... etc)
// 2 : mixed		(			<two byte offset>	: AT24C32/64/128/256, ... etc)
// 3 : rerserved
struct asus_write_sensor_info_s {
	unsigned char	sensor_number;
	unsigned char	pca9545_sw_value;
	unsigned char	slave_add;
	unsigned char	cmd_offset_byte[2];
	unsigned char	write_value_mask;	//For not sdr_check usage
    BITFIELD3(unsigned char, sdr_check : 1, protocol_type : 2, reserved : 5);	//sdr_check : must check the sensor number is in the SDRR or not?
} __attribute__ ((packed));
typedef struct asus_write_sensor_info_s asus_write_sensor_info_t;

#define ASUS_WRITE_SENSOR_TABLE_MAX_NUMBER		24
#define ASUS_WRITE_SENSOR_TABLE_FILE_PATH		"/tmp/wrsnr_table.cfg"



#define ASUS_MB_SUPPORT_MODEL_MAX_NUMBER 		16
#define ASUS_MB_SUPPORT_MODEL_MAX_LENGTH 		16
#define ASUS_MB_SUPPORT_MODEL_FILE_PATH			"/tmp/mbsupmdl.cfg"

struct asus_mb_sup_mdl_string_s {
	unsigned char model_name[ASUS_MB_SUPPORT_MODEL_MAX_LENGTH];
};
typedef struct asus_mb_sup_mdl_string_s asus_mb_sup_mdl_string_t;


int pp_bmc_dev_oem_asus_bmc_post_init(void);
#define ASUS_BMC_POST_INIT_MSGLED_VALUE_FILE_PATH	"/tmp/msgledval.cfg"

int pp_bmc_dev_oem_asus_bmc_init_top_read(void);
//#define ASUS_BMC_INIT_TOP_READ_FILE_FOLDER_PATH		"/etc/bmc/"
#define TOP_FILE_MAX_LENGTH		(32*1024)
#define TOP_FILE_SEEPROM_OFFSET	(1*64)		//Reserve 1 page size (64 bytes)

int pp_bmc_dev_oem_asus_get_mac(void);
int pp_bmc_dev_oem_asus_set_mac(void);
int pp_bmc_dev_oem_asus_read_eeprom(unsigned int seeprom_offset, unsigned char length, unsigned char *eeprom_buf);
int pp_bmc_dev_oem_asus_write_eeprom(unsigned int seeprom_offset, unsigned char length, unsigned char *eeprom_buf);
#define ASUS_MAC_FILE_PATH	"/tmp/macaddress"
#define MAC_FILE_SEEPROM_OFFSET		0		//6 bytes
#define ASUS_EEPROM_TIMER	0x10
#define ASUS_MODEL_NAME		0x20
#define KIRA_CONFIG_FILE_PATH	"/config/!config"

#endif /* !__BMC_DEV_OEM_ASUS_H__ */

