/*
 * <3BSD notice header>
 *
 * Copyright (C) 2003-2008 Raritan, Inc. <http://www.raritan.com/>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above
 *       copyright notice, this list of conditions and the following
 *       disclaimer in the documentation and/or other materials provided
 *       with the distribution.
 * 
 *     * Neither the name of [original copyright holder] nor the names of
 *       its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written
 *       permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * \file bmc_dev_sdrr.h
 *
 * Description: BMC Sensor Data Record Repository Device
 */

#ifndef __BMC_DEV_SDR_H__
#define __BMC_DEV_SDR_H__

#include <pp/bmc/ipmi_sdr.h>

/**
 * Initializes the BMC SDR Repository Device and registers it at the BMC core.
 *
 * @return PP_SUC (0) if success
 *         PP_ERR (-1) if error
 */
int pp_bmc_dev_sdrr_init(void);

/**
 * Finishes the BMC SDR Repository Device and unregisters it at the BMC core.
 */
void pp_bmc_dev_sdrr_cleanup(void);

/**
 * Returns whether SDRR is in persistent or transient mode.
 * Transient mode is default unless user writes into SDRR,
 * what will cause a state change to persistent mode.
 */
int pp_bmc_sdrr_is_persistent(void);

/**
 * Lookup SDR by key. This is used by the sensor device to find
 * an SDR for a sensor and do initialization (init agent functionality)
 */
ipmi_sdr_header_t* pp_bmc_sdrr_lookup_by_key_sensor(ipmi_sdr_key_sensor_t*key);

/**
 * Adds a SDR, without going through an IPMI command.
 * If SDR is in persistent mode, error will be returned.
 *
 * @param sdr the SDR to add, memory will be duplicated
 * @return new record id under which the record was stored
 *         or -1 if error
 */
unsigned short pp_bmc_sdrr_add_sdr_transiently(ipmi_sdr_header_t* sdr);

/**
 * Replaces the default management controller device locator record
 * 
 * @param sdr the new bmc info sdr, memory will be duplicated
 * @return new record id under which the record was stored
 *         or -1 if error
 */
unsigned short pp_bmc_sddr_replace_bmc_info_sdr(ipmi_sdr_header_t* sdr);

#endif /* !__BMC_DEV_SDR_H__ */
