/*
 * <3BSD notice header>
 *
 * Copyright (C) 2003-2008 Raritan, Inc. <http://www.raritan.com/>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above
 *       copyright notice, this list of conditions and the following
 *       disclaimer in the documentation and/or other materials provided
 *       with the distribution.
 * 
 *     * Neither the name of Raritan, Inc. nor the names of
 *       its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written
 *       permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * 
 */

#include <pp/base.h>
#include <pp/bmc/tp_i2c_chip.h>

typedef struct {
    /* chip superobject */
    pp_tp_i2c_chip_t base;
    
    /* our internal state */
    char adt_state;
    
    /* initial poweron delay - timeout handle */
    int init_to_hndl;

} pp_tp_adt7463_chip_t;


/* ppdoc
 * name:   ADT7463 chip
 * tpname: ADT7463_chip
 * desc:   ADT7463 chip object, needed by ADT7463 sensors and pwms.
 * arg 0:  [OBJ(I2C_COM_DEV)] i2cdev: i2c device to be used
 * arg 1:  [INT] i2c_addr:            i2c slave address of this device
 * arg 2:  [OBJ(COND)] powercond:     power on condition (chip will be
 * arg 2:                             initialized if condition changes to on,
 * arg 2:                             sensors won't be read while cond is false)
 * return: [OBJ(I2C_CHIP)]
 */
pp_tp_obj_t* pp_adt7463_chip_ctor(const char* id, vector_t* args);

/**
 * Check if adt7463 is ready for monitoring. Must be applied in 
 * addition to do_scan and existing sensor conditions.
 */
int pp_tp_adt7463_chip_is_ready(pp_tp_i2c_chip_t* this);

