/**
 * asusgeneral.h
 *
 * implements the ASUSGENERAL bit/byte/word controller chip/sensors
 * This file includes all related objects (chip, sensors)
 * 
 */

#ifndef __PP_SENSOR_ASUSGENERAL_H__
#define __PP_SENSOR_ASUSGENERAL_H__

#include <pp/bmc/topo_base_obj.h>

#define ASUSGENERAL_MODEL_STRING "asusgeneral"


pp_tp_obj_t* pp_sensor_asusgeneral_ctor(const char* id, vector_t* args);
/* ppdoc
 * name:   ASUSGENERAL chip
 * tpname: ASUSGENERAL
 * desc:   The ASUSGENERAL chip object. This object configures the ASUSGENERAL and
 * desc:   is needed for all ASUSGENERAL sensor.
 * desc:   See also: ASUSGENERALSens
 * arg 0:  [OBJ(I2C_COM_DEV)] comdev: i2c bus device to be used
 * arg 1:  [INT] i2caddr:             i2c slave address of this pseudo I2C chip device
 * arg 2:  [OBJ(COND)] powercond:     power on condition (chip will be
 * arg 2:                             initialized if condition changes to on,
 * arg 2:                             sensors won't be read while cond is false)
 * arg 3:  [INT, char] init_trx_mode:	(optional)
	    // trx_mode (bit 1,0)
	    // 0 : byte
	    // 1 : byte data
	    // 2 : word data
	    // 3 : byte data twice (register offset + 1)
	    // others : reserved
 * arg 4:  [INT, char] init_slaveadd:	(optional)
 * arg 5:  [INT, char] init_reg:		(optional)
 * arg 6:  [INT, short] init_andmask:	(optional)
 * arg 7:  [INT, short] init_or_value:	(optional)
 * return: [OBJ(I2C_CHIP)]
 */

pp_tp_obj_t* pp_sensor_asusgeneral_sens_ctor(const char* id, vector_t* args);
/* ppdoc
 * name:   ASUSGENERAL sensor
 * tpname: ASUSGENERALSens
 * desc:   The ASUSGENERAL sensor object, can dissolve to different sensors
 * desc:   depending on the arguments. Needs the ASUSGENERAL chip object, see ASUSGENERAL.
 * arg 0:  [OBJ(I2C_CHIP)] chip: i2c chip, must be an ASUSGENERAL
 * arg 1:  [OBJ(COND)] powercond:     power on condition (chip will be
 * arg 1:                             initialized if condition changes to on,
 * arg 1:                             sensors won't be read while cond is false)
 * arg 2:  [INT, char] sens_type:
 * arg 3:  [INT, char] reading_type:
 * arg 4:  [INT, char] unit_type:
 * arg 5:  [INT, char] analog_type:
 * arg 6:  [INT, short] sdr_mtol:
 * arg 7:  [INT, short] sdr_bacc:
 * arg 8:  [INT, char] sdr_bexp:
 * arg 9:  [INT, char] sdr_rexp:
 * arg 10:  [INT, char] config:
	    BITFIELD5(unsigned char, trx_mode_1 : 2,trx_mode_2 : 2, pre_en_trx_mode : 2, trx_2_en : 1, pre_trx_en : 1);
	    // trx_mode (bit 1,0)
	    // 0 : byte
	    // 1 : byte data
	    // 2 : word data
	    // 3 : byte data twice (register offset + 1)
 * arg 11:  [INT, char] slave_add:
 // check_b[0]
 * arg 12:  [INT, char]		reg:
 * arg 13:  [INT, short]	andmask:
 * arg 14:  [INT, char]		ok_value:
 * arg 15:  [INT, short]	pass_raw_return:
 * arg 16:  [INT, short]	raw_return:
 * arg 17:  [INT, short]	or_value:
        struct {
            unsigned char reg;			// unused
            unsigned short andmask;
            unsigned char ok_value;
            unsigned short pass_raw_return;
            unsigned short raw_return;
            unsigned short or_value;	//for pre_enable usage
        } byte;
        struct {
            unsigned char reg;
            unsigned short andmask;
            BITFIELD5(unsigned char, check_mode : 3,checked_return_type : 1,
            		divided_byte_return : 1, numerator_denominator : 1, reserved : 2);
            //	bit	2,1,0 (checking : <, =, >)
            //			000 : don't check (raw/divided byte return)
            //			001 : >		check
            //			010 : ==	check
            //			011 : >=	check
            //			100 : <		check
            //			101 : <>	check (range checking)
            //			110 : <=	check
            //			111 : !=	check
            //	bit	3 (for checked return type usage only)
            //			0 : raw byte return	(0 for checked fail and one byte return for checked pass)
            //			1 : discrete return (0: OK, 1:Fail)
			//	bit	4 (divided-byte return)
            //			0 : raw value divided disable
            //			1 : raw value divided enable
			//	bit	5 (divisor value as numerator or denominator)
            //			0 : divisor value as denominator
            //			1 : divisor value as numerator
            unsigned short divisor_value;
            unsigned short ok_eqhigh_limit;	//equal or high limit raw value
            unsigned short ok_enlow_limit;	//pre_enable usage or low limit raw value
        } byte_data;
        struct {
            unsigned char reg;
            unsigned short andmask;
            BITFIELD6(unsigned char, check_mode : 3,checked_return_type : 1,
            		divided_byte_return : 1, numerator_denominator : 1, hilo_byte_return : 1, reserved : 1);
            //	bit	2,1,0 (checking : <, =, >)
            //			000 : don't check (raw_high/raw_low/divided byte return)
            //			001 : >		check
            //			010 : ==	check
            //			011 : >=	check
            //			100 : <		check
            //			101 : <>	check (range checking)
            //			110 : <=	check
            //			111 : !=	check
            //	bit	3 (for checked return type usage only)
            //			0 : byte return	(0 for checked fail and one byte return for checked pass)
            //			1 : discrete return (0: OK, 1:Fail)
			//	bit	4 (divided-byte return), only when bit3=0
            //			0 : raw value divided disable
            //			1 : raw value divided enable
			//	bit	5 (divisor value as numerator or denominator), only when bit3=0 & bit4=1
            //			0 : divisor value as denominator
            //			1 : divisor value as numerator
			//	bit	6 (high/low byte raw return), only when bit3=0 & bit4=0
            //			0 : low byte raw return
            //			1 : high byte raw return
            unsigned short divisor_value;
            unsigned short ok_eqhigh_limit;	//equal or high limit raw value
            unsigned short ok_enlow_limit;	//pre_enable usage or low limit raw value
        } word_data;
 // check_b[1]
 * arg 18:  [INT, char]		reg:			(optional)
 * arg 19:  [INT, short]	andmask:		(optional)
 * arg 20:  [INT, char]		ok_value:		(optional)
 * arg 21:  [INT, short]	pass_raw_return:(optional)
 * arg 22:  [INT, short]	raw_return:		(optional)
 * arg 23:  [INT, short]	or_value:		(optional)
 // pre_enable : write the certain register before update sensor reading value
 * arg 24:  [INT, char]		reg:			(optional)
 * arg 25:  [INT, short]	andmask:		(optional)
 * arg 26:  [INT, char]		ok_value:		(optional)
 * arg 27:  [INT, short]	pass_raw_return:(optional)
 * arg 28:  [INT, short]	raw_return:		(optional)
 * arg 29:  [INT, short]	or_value:		(optional)

 * return: [OBJ(SENS_DEV)]
 */

pp_tp_obj_t* pp_asus_sensor_asuswritable_ctor(const char* id, vector_t* args);
/* ppdoc
 * name:   ASUSWritable sensor
 * tpname: ASUSWritableSens
 * desc:   The ASUSWritable sensor table entry.
 * desc:   Creat ASUS Writable sensor table entrys for asus_write_sensor_table used in /tmp/wrsrn_table.cfg
 * arg0:   [INT] sensor_number		: Logical FRU device ID			(type 11h sdr byte 7)
 * arg1:   [INT] channel_number		: ASUS I2C BUS channel number	(1,others=>0; 4=>1; 5=>2; 6=>4; 7=>8)
 * arg2:   [INT] slave_add			: FRU device slave address
 * arg3:   [INT] cmd_offset_byte[0]	: asus_fru_info_t struct "two_byte_offset" flag member data
 * arg4:   [INT] cmd_offset_byte[1]	: asus_fru_info_t struct "two_byte_offset" flag member data
 * arg5:   [INT] write_value_mask	: asus_fru_info_t struct "two_byte_offset" flag member data
 * arg6:   [INT] sdr_check			: asus_fru_info_t struct "two_byte_offset" flag member data
 * arg7:   [INT] protocol_type		: asus_fru_info_t struct "two_byte_offset" flag member data
			//protocol_type value mode definition
			// 0 : tx_byte		(send byte	<null offset>		: PCF8574, ... etc)
			// 1 : tx_byte_data	(write byte	<one byte offset>	: ADT7463, ... etc)
			// 2 : mixed		(			<two byte offset>	: AT24C32/64/128/256, ... etc)
			// 3 : rerserved
 * return: [OBJ(NULL)]
 */

pp_tp_obj_t* pp_asus_mb_support_model_ctor(const char* id, vector_t* args);
/* ppdoc
 * name:   ASUS Mother Board Support Model List
 * tpname: ASUSMBSupportMdl
 * desc:   The ASUS Mother Board Support Model List table entry adding.
 * desc:   Creat ASUS Mother Board Support Model List to file /tmp/mbsupmdl.cfg for /bmc/libpp_bmccore/src/bmc_dev_oem_asus.c usage
 * arg0:   [STRING] Model name string 0
 * arg1:   [STRING] Model name string 1 (optional)
 * arg2:   [STRING] Model name string 2 (optional)
 * arg3:   [STRING] Model name string 3 (optional)
 * arg4:   [STRING] Model name string 4 (optional)
 * arg5:   [STRING] Model name string 5 (optional)
 * arg6:   [STRING] Model name string 6 (optional)
 * arg7:   [STRING] Model name string 7 (optional)
 * arg8:   [STRING] Model name string 8 (optional)
 * arg9:   [STRING] Model name string 9 (optional)
 * arg10:  [STRING] Model name string 10 (optional)
 * arg11:  [STRING] Model name string 11 (optional)
 * arg12:  [STRING] Model name string 12 (optional)
 * arg13:  [STRING] Model name string 13 (optional)
 * arg14:  [STRING] Model name string 14 (optional)
 * arg15:  [STRING] Model name string 15 (optional)
 * return: [OBJ(NULL)]
 */

pp_tp_obj_t* pp_asus_bmc_post_init_msgled_value_ctor(const char* id, vector_t* args);
/* ppdoc
 * name:   ASUS BMC POST INIT message LED Init(OFF) IPMI OEM cmd value
 * tpname: ASUSPostInitMsgLedValue
 * desc:   The ASUS POST INIT for message LED OFF IPMI OEM cmd value in file adding.
 * desc:   Creat file /tmp/msgledval.cfg for /bmc/libpp_bmccore/src/bmc_dev_oem_asus.c usage
 * arg0:   [INT] ASUS IPMI OEM cmd value
 * return: [OBJ(NULL)]
 */

#endif /* __PP_SENSOR_ASUSGENERAL_H__ */
