/**
 * blackford_mch_sensor.h
 *
 * "Super class" for all BLACKFORD_MCH sensors
 * 
 */

#ifndef __BLACKFORD_MCH_SENSOR_H
#define __BLACKFORD_MCH_SENSOR_H

#include <pp/vector.h>
#include <pp/base.h>

#include <pp/bmc/topo_base_obj.h>
#include <pp/bmc/tp_i2c_chip.h>


/* ppdoc:
 * name:   BLACKFORD_MCH sensor
 * tpname: BLACKFORD_MCHsens
 * desc:   BLACKFORD_MCH sensor object, dissolves to different sensors depending
 * desc:   on the arguments. Relies on an BLACKFORD_MCH chip object.
 * arg 0: [OBJ(I2C_CHIP)] chip:  i2c chip to use, must be an BLACKFORD_MCH chip object
 * arg 1: [INT] sensor_no:       sensor number within the chip, whereas:
 * arg 1:                         0: channel 0, slot 0
 * arg 1:                         1: channel 0, slot 1
 * arg 1:                         2: channel 0, slot 2
 * arg 1:                         3: channel 0, slot 3
 * arg 1:                         4: channel 1, slot 0
 * arg 1:                         5: channel 1, slot 1
 * arg 1:                         6: channel 1, slot 2
 * arg 1:                         7: channel 1, slot 3
 * arg 1:                         8: channel 2, slot 0
 * arg 1:                         9: channel 2, slot 1
 * arg 1:                        10: channel 2, slot 2
 * arg 1:                        11: channel 2, slot 3
 * arg 1:                        12: channel 3, slot 0
 * arg 1:                        13: channel 3, slot 1
 * arg 1:                        14: channel 3, slot 2
 * arg 1:                        15: channel 3, slot 3
 * arg 2: [OBJ(COND)] scan_cond: (optional) scan_condition, sensor won't be
 * arg 2:                        read if condition is false
 * return: [OBJ(SENS_DEV)]
 */
pp_tp_obj_t* pp_blackford_mch_sensor_ctor(const char* id, vector_t* args);

#define PP_SENSOR_BLACKFORD_MCH_MAX_SENSOR_NUM 15

#endif /* __BLACKFORD_MCH_SENSOR_H */
