/**
 * pp_i2c_mux_pca9545.c
 *
 * A concrete implementation for the Philips PCA9545 i2c multiplexer
 * 
 */

#include <pp/base.h>

#include <pp/bmc/debug.h>
#include <pp/bmc/tp_i2c_mux.h>
#include <pp/bmc/topo_factory.h>

#include "pca9545_i2c_mux.h"

#define PP_I2C_MUX_9545_CHANNELS	4

/**
 * pp i2c device constructor
 */
pp_tp_obj_t* pp_i2c_mux_pca9545_ctor (const char* id, vector_t* args) {
    pp_strstream_t err = PP_STRSTREAM_INITIALIZER;  
    pp_i2c_mux_pca9545_t* o = NULL;

    pp_tp_i2c_comdev_t* i2cdev;
    u_char i2caddr;
    u_char channel;

    if (pp_tp_arg_scanf(args, 0, &err, "o<i>d<c>d<c>", &i2cdev, &i2caddr, &channel)
	!= 3) {
        pp_bmc_log_error("%s(): '%s' failed: %s (%s)",
			 ___F, id, strerror(errno), pp_strstream_buf(&err));
	goto bail;
    } else if (channel > PP_I2C_MUX_9545_CHANNELS - 1) {
        pp_bmc_log_error("%s(): '%s' failed: invalid channel number: %d (max is %d)",
			 ___F, id, channel, PP_I2C_MUX_9545_CHANNELS);
        goto bail;
    }

    o = malloc(sizeof(pp_i2c_mux_pca9545_t));  

    pp_i2c_mux_pca9545_init(o, id, i2cdev, i2caddr, channel);

 bail:
    pp_strstream_free(&err);
    return (pp_tp_obj_t*)o;
}

void pp_i2c_mux_pca9545_dtor (pp_tp_obj_t* d)
{
    pp_i2c_mux_pca9545_cleanup(d);
    free(d);
}

static int pp_i2c_mux_pca9545_switch_channel(pp_tp_i2c_mux_t* d)
{   
    return d->parent->tx_byte(d->parent, d->i2caddr, 1 << (d->channel));
}

static int pp_i2c_mux_pca9545_disable_channels(pp_tp_i2c_mux_t* d)
{
    return d->parent->tx_byte(d->parent, d->i2caddr, 0);
}

void pp_i2c_mux_pca9545_init(pp_i2c_mux_pca9545_t* d,
			     const char * id,
			     pp_tp_i2c_comdev_t* parent,
			     u_char i2caddr,
			     u_char channel)
{
    /* call super */
    pp_tp_i2c_mux_init((pp_tp_i2c_mux_t*)d, PP_TP_I2C_MUX, id,
		       pp_i2c_mux_pca9545_dtor,
		       pp_i2c_mux_pca9545_switch_channel,
		       pp_i2c_mux_pca9545_disable_channels,
		       parent,
		       i2caddr,
		       channel);
}

