/**
 * w83627dhg_1.h
 *
 * Implements the Winbond83627HF Monitor / Fan controller chip
 * Includes the i2c chip object as well as the sensor object
 * 
 * (c) 2008 ASUS Tek, 2008/01/16, east_zhao@asus.com.tw
 */

#ifndef __PP_SENSOR_W83627DHG_1_H__
#define __PP_SENSOR_W83627DHG_1_H__

#include <pp/bmc/topo_base_obj.h>


/* ppdoc
 * name:   W83627DHG chip
 * tpname: W83627DHG
 * desc:   The W83627DHG chip object. This object configures the W83627DHG and
 * desc:   is needed for all W83627DHG sensor.
 * desc:   See also: W83627DHGSens
 * arg 0:  [OBJ(I2C_COM_DEV)] comdev: i2c device to be used
 * arg 1:  [INT] i2caddr:             i2c slave address of this device
 * arg 2:  [OBJ(COND)] powercond:     power on condition (chip will be
 * arg 2:                             initialized if condition changes to on,
 * arg 2:                             sensors won't be read while cond is false)
 * arg 3:  [INT] M:				            M value
 * arg 4:  [INT] B:				            B Value
 * arg 5:  [INT] Rx:				          Rx Value
 * arg 6:  [INT] Bx:				          Bx Value
 * return: [OBJ(I2C_CHIP)]
 */
pp_tp_obj_t* pp_sensor_w83627dhg_1_ctor(const char* id, vector_t* args);

/* ppdoc
 * name:   W83627DHG sensor
 * tpname: W83627DHGSens
 * desc:   The W83627DHG sensor object, can dissolve to different sensors
 * desc:   depending on the arguments. Needs the W83627DHG chip object, see W83627DHG.
 * arg 0:  [OBJ(I2C_CHIP)] chip: i2c chip, must be an W83627DHG
 * arg 1:  [INT] sensor_no:      sensor number within chip
 * arg 1:                        0: VCOREA
 * arg 1:                        1: VINR0
 * arg 1:                        2: 33VIN
 * arg 1:                        3: 5VIN
 * arg 1:                        4: 12VIN
 * arg 1:                        5: N12VIN
 * arg 1:                        6: N5VIN
 * arg 1:                        7: 5VSB
 * arg 1:                        8: VBAT
 * arg 1:                        9: FAN1
 * arg 1:                        10: FAN2
 * arg 1:                        11: FAN3
 * arg 1:                        12: VTIN1
 * arg 1:                        13: VTIN2
 * arg 1:                        14: VTIN3
 * return: [OBJ(SENS_DEV)]
 */
pp_tp_obj_t* pp_sensor_w83627dhg_1_sens_ctor(const char* id, vector_t* args);

#endif /* __PP_SENSOR_W83627DHG_1_H__ */



#ifndef __PP_SENSOR_W83627HF_H__

#define W83627DHG_MODEL_STRING "w83627dhg"

/* some register symbols, as per spec W83627DHG.pf */
#define W83627DHG_REG_VALUE_VCOREA		0x20	// Bank 0
#define W83627DHG_REG_VALUE_VIN0		0x21	// Bank 0
#define W83627DHG_REG_VALUE_AVCC 		0x22	// Bank 0
#define W83627DHG_REG_VALUE_3VCC		0x23	// Bank 0
#define W83627DHG_REG_VALUE_VIN1 		0x24	// Bank 0
#define W83627DHG_REG_VALUE_VIN2  		0x25	// Bank 0
#define W83627DHG_REG_VALUE_VIN3 		0x26	// Bank 0

#define W83627DHG_REG_VALUE_SYSTIN		0x27	// Bank 0

#define W83627DHG_REG_VALUE_CPUTIN_H		0x50	// Bank 1
#define W83627DHG_REG_VALUE_CPUTIN_L		0x51	// Bank 1
#define W83627DHG_REG_VALUE_AUXTIN_H		0x50	// Bank 2
#define W83627DHG_REG_VALUE_AUXTIN_L		0x51	// Bank 2

#define W83627DHG_REG_VALUE_SYSFANIN		0x28	// Bank 0
#define W83627DHG_REG_VALUE_CPUFANIN0		0x29	// Bank 0
#define W83627DHG_REG_VALUE_AUXFANIN0		0x2A	// Bank 0
#define W83627DHG_REG_VALUE_CPUFANIN1		0x3F	// Bank 0
#define W83627DHG_REG_VALUE_AUXFANIN1		0x53	// Bank 5

#define W83627DHG_REG_VALUE_5VSB		0x50	// Bank 5
#define W83627DHG_REG_VALUE_VBAT		0x51	// Bank 5

#define W83627DHG_REG_CONFIG_REG_1		0x40	// Bank 0
#define W83627DHG_REG_BANK_SEL			0x4E	// Bank 0
#define W83627DHG_REG_FAN_DEVISOR_1		0x47	// Bank 0 7-6: CPUFANIN0 bit0-1, 5-4: SYSFANIN bit 0-1
#define W83627DHG_REG_FAN_DEVISOR_2		0x4B	// Bank 0 7-6: AUXFANIN0 bit0-1
#define W83627DHG_REG_FAN_DEVISOR_3		0x4C	// Bank 0 7: CPUFANIN1 bit 2
#define W83627DHG_REG_FAN_DEVISOR_4		0x59	// Bank 0 7: AUXFANIN1 bit 2, 3-2: AUXFANIN1 bit0-1, 1-0:CPUFANIN1 bit0-1
#define W83627DHG_REG_FAN_DEVISOR_5		0x5D	// Bank 0 7: AUXFANIN0 bit 2, 6: CPUFANIN0 bit2,  5:SYSFANIN bit 2
#define W83627DHG_REG_FAN_DEVISOR_BANK		0x00

#endif /* __PP_SENSOR_W83627DHG_H__ */
