/*
 * <3BSD notice header>
 *
 * Copyright (C) 2003-2008 Raritan, Inc. <http://www.raritan.com/>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above
 *       copyright notice, this list of conditions and the following
 *       disclaimer in the documentation and/or other materials provided
 *       with the distribution.
 * 
 *     * Neither the name of [original copyright holder] nor the names of
 *       its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written
 *       permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * w83793g.h
 *
 * implements the w83793g chip object
 */

#ifndef __PP_SENSOR_W83793G_H__
#define __PP_SENSOR_W83793G_H__

#include <pp/bmc/topo_base_obj.h>
#include <pp/bmc/tp_i2c_chip.h>

typedef struct pp_tp_w83793g_chip_s {
    pp_tp_i2c_chip_t base;
    unsigned char pwm_pre_scale;
} pp_tp_w83793g_chip_t;


/* ppdoc
 * name:   W83793G chip
 * tpname: W83793G
 * desc:   Common object for all w83793 sensors, pwms and gpios.
 * arg 0:  [OBJ(I2C_COM_DEV)] i2cdev: i2c device to be used
 * arg 1:  [INT] i2c_addr:            i2c slave address of this device
 * arg 2:  [OBJ(COND)] powercond:     power on condition (chip will be
 * arg 2:                             initialized if condition changes to on,
 * arg 2:                             sensors won't be read while cond is false)
 * arg 3:  [INT] gpio_mask:           GPIO mask, 12 bit, 1 enables according GPIO
 * arg 4:  [INT] gpio_dir:            GPIO in/out mask, 12 bit, 1 marks GPIO as output
 * arg 5:  [INT] pwm_prescaler:       PWM Pre Scale Register, 8bit as per Spec,
 * arg 5:                             currently identical for all 5 PWMs,
 * arg 5:                             will be written to 0x80, 0x82, 0x93, 0xA0, 0xA1
 * return: [OBJ(I2C_CHIP)]
 */
pp_tp_obj_t* pp_sensor_w83793g_ctor(const char* id, vector_t* args);

#define W83793G_MODEL_STRING "w83793g"

#define W83793G_VOLTAGE_CORE1	0x10
#define W83793G_VOLTAGE_CORE2	0x11
#define W83793G_VOLTAGE_VTT	0x12
#define W83793G_VOLTAGE_1_5V	0x14
#define W83793G_VOLTAGE_1_8V	0x15
#define W83793G_VOLTAGE_3V	0x16
#define W83793G_VOLTAGE_12V	0x17
#define W83793G_VOLTAGE_5V	0x18
#define W83793G_VOLTAGE_5VSB	0x19
#define W83793G_VOLTAGE_VBAT	0x1A

//#define W83793G_PWM_MAX_NUMBER 5

#endif /* __PP_SENSOR_W83793G_H__ */
