/*
 * <3BSD notice header>
 *
 * Copyright (C) 2003-2008 Raritan, Inc. <http://www.raritan.com/>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above
 *       copyright notice, this list of conditions and the following
 *       disclaimer in the documentation and/or other materials provided
 *       with the distribution.
 * 
 *     * Neither the name of [original copyright holder] nor the names of
 *       its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written
 *       permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * w83793g_sensor.h
 *
 * "Super class" for all Winbond W83793G sensors
 * 
 * (c) 2006 Supermicro, 2006/04/04, Edward Pan<edwardp@supermicro.com>
 * (c) 2006 ASUSTek, 2006/10/05, JinCheng
 */

#ifndef __W83793G_SENSOR_H
#define __W83793G_SENSOR_H

#include <pp/bmc/topo_base_obj.h>

/* ppdoc
 * name:   W83793G sensor
 * tpname: W83793G
 * desc:   A sensor object for the w83793 chip. Dessolves to different sensors
 * desc:   depending on the arguments.
 * arg 0:  [OBJ(I2C_CHIP)] chip: i2c chip, must be an W83793g
 * arg 1:  [INT] sensor_no:      sensor number within the chip, whereas:
 * arg 1:                         0: System Temperature 1(Front)	[THR1]
 * arg 1:                         1: System Temperature 2(Rear)		[THR2]
 * arg 1:                         2: CPU1_core1(CPU1) Temperature	[1_D+/-]
 * arg 1:                         3: CPU1_core2(CPU3) Temperature	[3_D+/-]
 * arg 1:                         4: CPU2_core1(CPU2) Temperature	[2_D+/-]
 * arg 1:                         5: CPU2_core2(CPU4) Temperature	[4_D+/-]
 * arg 1:                         6: Vcore 1						[VcoreA]
 * arg 1:                         7: Vcore 2						[VcoreB]
 * arg 1:                         8: Vtt							[VTT]
 * arg 1:                         9: +1.5V/Vcore 3/Mem_P1			[VSEN1]
 * arg 1:                        10: +1.8V/Vcore 4/Mem_P2			[VSEN2]
 * arg 1:                        11: +3.3V							[+3VSEN]
 * arg 1:                        12: +12V							[+12VSEN]
 * arg 1:                        13: +5V							[5VDD]
 * arg 1:                        14: +5VSB							[5VSB]
 * arg 1:                        15: VBAT							[VBAT]
 * arg 1:                        16: FAN1(CPU_FAN1)					[FANIN1]
 * arg 1:                        17: FAN2(CPU_FAN2)					[FANIN2]
 * arg 1:                        18: FAN3(FRONT_FAN1)				[FANIN3]
 * arg 1:                        19: FAN4(FRONT_FAN2)				[FANIN4]
 * arg 1:                        20: FAN5(FRONT_FAN3)				[FANIN5]
 * arg 1:                        21: FAN6(FRONT_FAN4)				[FANIN6]
 * arg 1:                        22: FAN7(REAR_FAN1)				[FANIN7]
 * arg 1:                        23: FAN8(REAR_FAN2)				[FANIN8]
 * arg 1:                        24: FAN9(FBD_FAN1)(FRONT_FAN5)		[FANIN9]
 * arg 1:                        25: FAN10(FBD_FAN2)(FRONT_FAN6)	[FANIN10]
 * arg 1:                        26: FAN11(CPU_FAN3)				[FANIN11]
 * arg 1:                        27: FAN12(CPU_FAN4)				[FANIN12]
 * arg 1:                        28: Chassis intrusion				[CASEOPEN#]
 * arg 2: [OBJ(COND)] scan_cond: (optional) scan condition, sensors won't be
 * arg 2:                        read if condition is false
 * return: [OBJ(SENS_DEV)]
 */
pp_tp_obj_t* pp_sensor_w83793g_sens_ctor(const char* id, vector_t* args);

#define PP_SENSOR_W83793G_MAX_SENSOR_NUM 28

#endif /* __W83793G_SENSOR_H */
