/*
 * <3BSD notice header>
 *
 * Copyright (C) 2003-2008 Raritan, Inc. <http://www.raritan.com/>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above
 *       copyright notice, this list of conditions and the following
 *       disclaimer in the documentation and/or other materials provided
 *       with the distribution.
 * 
 *     * Neither the name of [original copyright holder] nor the names of
 *       its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written
 *       permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * \file ipmi_oem_pp.c
 *
 * Description: Peppercon IPMI OEM commands
 */

#include <config.h>

#include <ipmitool/ipmi.h>
#include <ipmitool/ipmi_oem_pp.h>
#include <ipmitool/ipmi_intf.h>
#include <ipmitool/ipmi_print.h>
#include <ipmitool/ipmi_error.h>
#include <ipmitool/ipmi_strings.h>

static int ipmi_oem_pp_set_pwm(struct ipmi_intf * intf,
                        pp_ipmi_parameter_t *params,
                        pp_ipmi_return_t *ret UNUSED,
                        int * error)
{
    const char *cmd_name = "[OEM Peppercon] Set PWM Params";
    struct ipmi_rs *rsp;
    struct ipmi_rq req;

    unsigned char b[2];
    b[0] = (unsigned char)params->data.oem_pp_set_pwm.pwm_id;
    b[1] = (unsigned char)params->data.oem_pp_set_pwm.duty_cycle;

    memset(&req, 0, sizeof(req));
    req.msg.netfn = IPMI_NETFN_OEM_PP;
    req.msg.cmd = IPMI_SUBCMD_OEM_PP_SET_PWM;
    req.msg.data_len = 2;
    req.msg.data = b;

    rsp = intf->sendrecv(intf, &req, error);
    if (!rsp) {
        ipmi_printf("'%s' failed\n", cmd_name);
        return -1;
    }
    if (rsp->ccode) {
        ipmi_printf("'%s' failed: %s\n", cmd_name,
               val2str(rsp->ccode, completion_code_vals));
        return -1;
    }

    return 0;
}


static int ipmi_oem_pp_set_locator_led(struct ipmi_intf * intf,
                        pp_ipmi_parameter_t *params,
                        pp_ipmi_return_t *ret UNUSED,
                        int * error)
{
    const char *cmd_name = "[OEM Peppercon] Set Locator LED";
    struct ipmi_rs *rsp;
    struct ipmi_rq req;

    unsigned char b[2];
    b[0] = (unsigned char)params->data.oem_pp_set_locator_led.sensor_num;
    b[1] = (unsigned char)params->data.oem_pp_set_locator_led.value;

    memset(&req, 0, sizeof(req));
    req.msg.netfn = IPMI_NETFN_OEM_ASUS;
    req.msg.cmd = IPMI_CMD_ASUS_READ_WRITE_SENSOR_VALUE;
    req.msg.data_len = 2;
    req.msg.data = b;

    rsp = intf->sendrecv(intf, &req, error);
    if (!rsp) {
        ipmi_printf("'%s' failed\n", cmd_name);
        return -1;
    }
    if (rsp->ccode) {
        ipmi_printf("'%s' failed: %s\n", cmd_name,
               val2str(rsp->ccode, completion_code_vals));
        return -1;
    }

    return 0;
}

int ipmi_oem_pp_main(struct ipmi_intf * intf,
                     int subcmd,
                     pp_ipmi_parameter_t *params,
                     pp_ipmi_return_t *ret,
                     int * error)
{
    switch ((pp_ipmi_kvm_subcommand_t) subcmd) {
/* TODO:
	case PP_IPMI_OEM_PP_GET_PWM:
	    return ipmi_oem_pp_get_pwm(intf, params, ret, error);
	    break;
*/
	case PP_IPMI_OEM_PP_SET_PWM:
	    return ipmi_oem_pp_set_pwm(intf, params, ret, error);
	    break;
	case IPMI_SUBCMD_OEM_PP_ASUS_LOCATOR_LED:
	    return ipmi_oem_pp_set_locator_led(intf, params, ret, error);
	default:
	    ipmi_printf("Invalid OEM Peppercon command: %d\n", subcmd);
	    ipmi_set_error(error, IPMI_ERROR_INVALID_COMMAND);
	    return -1;
    }
}

